# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 6.0.2
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from empire_platform_api_public_client_legacy.models.bidding_configuration import BiddingConfiguration  # noqa: E501

class TestBiddingConfiguration(unittest.TestCase):
    """BiddingConfiguration unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BiddingConfiguration:
        """Test BiddingConfiguration
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BiddingConfiguration`
        """
        model = BiddingConfiguration()  # noqa: E501
        if include_optional:
            return BiddingConfiguration(
                values = [
                    empire_platform_api_public_client_legacy.models.bidding_configuration_values.BiddingConfiguration_values(
                        direction = 'GB_NL', 
                        configuration = empire_platform_api_public_client_legacy.models.bidding_configuration_timescale_options.BiddingConfigurationTimescaleOptions(
                            long_term = empire_platform_api_public_client_legacy.models.bidding_configuration_per_direction.BiddingConfigurationPerDirection(
                                maximum_bid_capacity = 56, 
                                warning_bid_price = 1.337, 
                                maximum_bid_price = 1.337, ), 
                            day_ahead = empire_platform_api_public_client_legacy.models.bidding_configuration_per_direction.BiddingConfigurationPerDirection(), 
                            intra_day = , ), )
                    ],
                secondary_market_notices = empire_platform_api_public_client_legacy.models.bidding_configuration_secondary_market_notices.BiddingConfiguration_secondaryMarketNotices(
                    long_term = True, 
                    day_ahead = True, 
                    intra_day = True, )
            )
        else:
            return BiddingConfiguration(
                values = [
                    empire_platform_api_public_client_legacy.models.bidding_configuration_values.BiddingConfiguration_values(
                        direction = 'GB_NL', 
                        configuration = empire_platform_api_public_client_legacy.models.bidding_configuration_timescale_options.BiddingConfigurationTimescaleOptions(
                            long_term = empire_platform_api_public_client_legacy.models.bidding_configuration_per_direction.BiddingConfigurationPerDirection(
                                maximum_bid_capacity = 56, 
                                warning_bid_price = 1.337, 
                                maximum_bid_price = 1.337, ), 
                            day_ahead = empire_platform_api_public_client_legacy.models.bidding_configuration_per_direction.BiddingConfigurationPerDirection(), 
                            intra_day = , ), )
                    ],
                secondary_market_notices = empire_platform_api_public_client_legacy.models.bidding_configuration_secondary_market_notices.BiddingConfiguration_secondaryMarketNotices(
                    long_term = True, 
                    day_ahead = True, 
                    intra_day = True, ),
        )
        """

    def testBiddingConfiguration(self):
        """Test BiddingConfiguration"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 6.0.2
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictInt, confloat, conint
from empire_platform_api_public_client_legacy.models.buy_now_offer_mtu_status import BuyNowOfferMtuStatus
from empire_platform_api_public_client_legacy.models.date_time_period import DateTimePeriod

class BuyNowOfferMtus(BaseModel):
    """
    BuyNowOfferMtus
    """
    mtu: datetime = Field(default=..., description="The first moment (inclusive) of an MTU period  - theoretically can be sent and received with any zone offset (until it marks the desired **absolute MTU start point** on the timeline) - in practice it is advised to transfer it in UTC timezone (with Z offset, \"Zulu time\") - ISO 8601 compliant string in `yyyy-mm-ddThh:mm:ss.SSSZ` format - only with `XX:00:00`, `XX:15:00`, `XX:30:00` and `XX:45:00` time parts are valid values (depending on MTU size) ")
    validity_period: Optional[DateTimePeriod] = Field(default=None, alias="validityPeriod")
    locked: StrictBool = Field(...)
    current_price: Union[confloat(multiple_of=0.01, strict=True), conint(strict=True)] = Field(default=..., alias="currentPrice", description="Currency value in Euros (€), accepted with a precision of maximum 2 decimal places")
    next_price: Optional[Union[confloat(multiple_of=0.01, strict=True), conint(strict=True)]] = Field(default=None, alias="nextPrice", description="Currency value in Euros (€), accepted with a precision of maximum 2 decimal places")
    oc: StrictInt = Field(default=..., description="Capacity value in kilowatts (kW) - the required system precision allows for handling capacity values as integers")
    status: BuyNowOfferMtuStatus = Field(...)
    allocated_ac: StrictInt = Field(default=..., alias="allocatedAc", description="Capacity value in kilowatts (kW) - the required system precision allows for handling capacity values as integers")
    participant_count: Optional[conint(strict=True, ge=0)] = Field(default=None, alias="participantCount", description="Natural numbers {0, 1, 2, 3, ...} used for counting elements")
    total_price: Union[confloat(multiple_of=0.01, strict=True), conint(strict=True)] = Field(default=..., alias="totalPrice", description="Currency value in Euros (€), accepted with a precision of maximum 2 decimal places")
    expired_oc: Optional[StrictInt] = Field(default=None, alias="expiredOc", description="Capacity value in kilowatts (kW) - the required system precision allows for handling capacity values as integers")
    __properties = ["mtu", "validityPeriod", "locked", "currentPrice", "nextPrice", "oc", "status", "allocatedAc", "participantCount", "totalPrice", "expiredOc"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> BuyNowOfferMtus:
        """Create an instance of BuyNowOfferMtus from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of validity_period
        if self.validity_period:
            _dict['validityPeriod'] = self.validity_period.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> BuyNowOfferMtus:
        """Create an instance of BuyNowOfferMtus from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return BuyNowOfferMtus.parse_obj(obj)

        _obj = BuyNowOfferMtus.parse_obj({
            "mtu": obj.get("mtu"),
            "validity_period": DateTimePeriod.from_dict(obj.get("validityPeriod")) if obj.get("validityPeriod") is not None else None,
            "locked": obj.get("locked"),
            "current_price": obj.get("currentPrice"),
            "next_price": obj.get("nextPrice"),
            "oc": obj.get("oc"),
            "status": obj.get("status"),
            "allocated_ac": obj.get("allocatedAc"),
            "participant_count": obj.get("participantCount"),
            "total_price": obj.get("totalPrice"),
            "expired_oc": obj.get("expiredOc")
        })
        return _obj





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 6.0.2
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from empire_platform_api_public_client_legacy.models.auction_overview import AuctionOverview  # noqa: E501

class TestAuctionOverview(unittest.TestCase):
    """AuctionOverview unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AuctionOverview:
        """Test AuctionOverview
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AuctionOverview`
        """
        model = AuctionOverview()  # noqa: E501
        if include_optional:
            return AuctionOverview(
                auctions = [
                    empire_platform_api_public_client_legacy.models.auction.Auction(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        display_id = 'BDL-NL-GB-E-BASE---220305-01', 
                        product_type = 'LT_EXPLICIT_MULTI_ANNUAL', 
                        border_direction = 'GB_NL', 
                        status = 'CREATED', 
                        processing = True, 
                        delivery_period = empire_platform_api_public_client_legacy.models.mtu_period.MtuPeriod(
                            from_mtu_start = '2022-01-04T10:00:00.000Z', 
                            to_mtu_end = '2022-01-04T11:00:00.000Z', ), 
                        bidding_period = empire_platform_api_public_client_legacy.models.date_time_period.DateTimePeriod(
                            start = '2022-01-04T00:00:00.000Z', 
                            end = '2022-01-04T00:00:00.000Z', ), 
                        name = '2022 May Auction', 
                        pre_bidding_allowed = True, 
                        offered_capacity = 56, 
                        current_participant_bid_count = 0, 
                        returns_window_close = '2022-01-04T00:00:00.000Z', )
                    ],
                buy_now_offers = [
                    empire_platform_api_public_client_legacy.models.buy_now_offer_overview_item.BuyNowOfferOverviewItem(
                        display_id = '', 
                        validity_period = empire_platform_api_public_client_legacy.models.date_time_period.DateTimePeriod(
                            start = '2022-01-04T00:00:00.000Z', 
                            end = '2022-01-04T00:00:00.000Z', ), 
                        delivery_period = empire_platform_api_public_client_legacy.models.mtu_period.MtuPeriod(
                            from_mtu_start = '2022-01-04T10:00:00.000Z', 
                            to_mtu_end = '2022-01-04T11:00:00.000Z', ), 
                        product_type = 'LT_EXPLICIT_MULTI_ANNUAL', 
                        direction = 'GB_NL', )
                    ]
            )
        else:
            return AuctionOverview(
                auctions = [
                    empire_platform_api_public_client_legacy.models.auction.Auction(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        display_id = 'BDL-NL-GB-E-BASE---220305-01', 
                        product_type = 'LT_EXPLICIT_MULTI_ANNUAL', 
                        border_direction = 'GB_NL', 
                        status = 'CREATED', 
                        processing = True, 
                        delivery_period = empire_platform_api_public_client_legacy.models.mtu_period.MtuPeriod(
                            from_mtu_start = '2022-01-04T10:00:00.000Z', 
                            to_mtu_end = '2022-01-04T11:00:00.000Z', ), 
                        bidding_period = empire_platform_api_public_client_legacy.models.date_time_period.DateTimePeriod(
                            start = '2022-01-04T00:00:00.000Z', 
                            end = '2022-01-04T00:00:00.000Z', ), 
                        name = '2022 May Auction', 
                        pre_bidding_allowed = True, 
                        offered_capacity = 56, 
                        current_participant_bid_count = 0, 
                        returns_window_close = '2022-01-04T00:00:00.000Z', )
                    ],
                buy_now_offers = [
                    empire_platform_api_public_client_legacy.models.buy_now_offer_overview_item.BuyNowOfferOverviewItem(
                        display_id = '', 
                        validity_period = empire_platform_api_public_client_legacy.models.date_time_period.DateTimePeriod(
                            start = '2022-01-04T00:00:00.000Z', 
                            end = '2022-01-04T00:00:00.000Z', ), 
                        delivery_period = empire_platform_api_public_client_legacy.models.mtu_period.MtuPeriod(
                            from_mtu_start = '2022-01-04T10:00:00.000Z', 
                            to_mtu_end = '2022-01-04T11:00:00.000Z', ), 
                        product_type = 'LT_EXPLICIT_MULTI_ANNUAL', 
                        direction = 'GB_NL', )
                    ],
        )
        """

    def testAuctionOverview(self):
        """Test AuctionOverview"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 6.0.2
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Union
from pydantic import BaseModel, Field, confloat, conint

class CreditUtilizationOverviewData(BaseModel):
    """
    CreditUtilizationOverviewData
    """
    uninvoiced_liability: Union[confloat(multiple_of=0.01, strict=True), conint(strict=True)] = Field(default=..., alias="uninvoicedLiability", description="Currency value in Euros (€), accepted with a precision of maximum 2 decimal places")
    uninvoiced_compensation: Union[confloat(multiple_of=0.01, strict=True), conint(strict=True)] = Field(default=..., alias="uninvoicedCompensation", description="Currency value in Euros (€), accepted with a precision of maximum 2 decimal places")
    pending_bids_price: Union[confloat(multiple_of=0.01, strict=True), conint(strict=True)] = Field(default=..., alias="pendingBidsPrice", description="Currency value in Euros (€), accepted with a precision of maximum 2 decimal places")
    credit_utilization: Union[confloat(multiple_of=0.01, strict=True), conint(strict=True)] = Field(default=..., alias="creditUtilization", description="Currency value in Euros (€), accepted with a precision of maximum 2 decimal places")
    __properties = ["uninvoicedLiability", "uninvoicedCompensation", "pendingBidsPrice", "creditUtilization"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CreditUtilizationOverviewData:
        """Create an instance of CreditUtilizationOverviewData from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CreditUtilizationOverviewData:
        """Create an instance of CreditUtilizationOverviewData from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CreditUtilizationOverviewData.parse_obj(obj)

        _obj = CreditUtilizationOverviewData.parse_obj({
            "uninvoiced_liability": obj.get("uninvoicedLiability"),
            "uninvoiced_compensation": obj.get("uninvoicedCompensation"),
            "pending_bids_price": obj.get("pendingBidsPrice"),
            "credit_utilization": obj.get("creditUtilization")
        })
        return _obj





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 6.0.2
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from empire_platform_api_public_client_legacy.api.bidding_configuration_api import BiddingConfigurationApi  # noqa: E501


class TestBiddingConfigurationApi(unittest.TestCase):
    """BiddingConfigurationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = BiddingConfigurationApi()

    def tearDown(self) -> None:
        self.api.api_client.close()

    def test_get_bidding_configuration(self) -> None:
        """Test case for get_bidding_configuration

        """
        pass

    def test_update_bidding_configuration(self) -> None:
        """Test case for update_bidding_configuration

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 6.0.2
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from empire_platform_api_public_client_legacy.api.participant_dashboard_api import ParticipantDashboardApi  # noqa: E501


class TestParticipantDashboardApi(unittest.TestCase):
    """ParticipantDashboardApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ParticipantDashboardApi()

    def tearDown(self) -> None:
        self.api.api_client.close()

    def test_get_participant_dashboard_default_bids_and_nominations(self) -> None:
        """Test case for get_participant_dashboard_default_bids_and_nominations

        """
        pass

    def test_get_participant_dashboard_finance_overview(self) -> None:
        """Test case for get_participant_dashboard_finance_overview

        """
        pass

    def test_get_participant_dashboard_interconnector_capacity(self) -> None:
        """Test case for get_participant_dashboard_interconnector_capacity

        """
        pass

    def test_get_participant_dashboard_interconnector_capacity_graph(self) -> None:
        """Test case for get_participant_dashboard_interconnector_capacity_graph

        """
        pass

    def test_get_participant_dashboard_messages(self) -> None:
        """Test case for get_participant_dashboard_messages

        """
        pass

    def test_get_participant_dashboard_netted_nominations(self) -> None:
        """Test case for get_participant_dashboard_netted_nominations

        """
        pass

    def test_get_participant_dashboard_next_auctions_and_nomination_gates(self) -> None:
        """Test case for get_participant_dashboard_next_auctions_and_nomination_gates

        """
        pass

    def test_get_participant_dashboard_transmission_rights_and_nominations(self) -> None:
        """Test case for get_participant_dashboard_transmission_rights_and_nominations

        """
        pass

    def test_get_participant_dashboard_transmission_rights_and_nominations_graph(self) -> None:
        """Test case for get_participant_dashboard_transmission_rights_and_nominations_graph

        """
        pass

    def test_get_participant_dashboard_upcoming_long_term_auctions(self) -> None:
        """Test case for get_participant_dashboard_upcoming_long_term_auctions

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 6.0.2
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from empire_platform_api_public_client_legacy.models.day_ahead_or_intra_day_auction_results_mtu import DayAheadOrIntraDayAuctionResultsMtu  # noqa: E501

class TestDayAheadOrIntraDayAuctionResultsMtu(unittest.TestCase):
    """DayAheadOrIntraDayAuctionResultsMtu unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DayAheadOrIntraDayAuctionResultsMtu:
        """Test DayAheadOrIntraDayAuctionResultsMtu
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DayAheadOrIntraDayAuctionResultsMtu`
        """
        model = DayAheadOrIntraDayAuctionResultsMtu()  # noqa: E501
        if include_optional:
            return DayAheadOrIntraDayAuctionResultsMtu(
                mtu = '2022-01-04T10:00:00.000Z',
                requested_capacity = 56,
                allocated_trs = 56,
                marginal_price = 1.337,
                participant_count = 0,
                successful_participant_count = 0,
                bid_count = 0
            )
        else:
            return DayAheadOrIntraDayAuctionResultsMtu(
                mtu = '2022-01-04T10:00:00.000Z',
                requested_capacity = 56,
                allocated_trs = 56,
                marginal_price = 1.337,
                participant_count = 0,
                successful_participant_count = 0,
                bid_count = 0,
        )
        """

    def testDayAheadOrIntraDayAuctionResultsMtu(self):
        """Test DayAheadOrIntraDayAuctionResultsMtu"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 6.0.2
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field
from empire_platform_api_public_client_legacy.models.subscription_notification_preference import SubscriptionNotificationPreference
from empire_platform_api_public_client_legacy.models.subscription_notification_preference_with_email import SubscriptionNotificationPreferenceWithEmail

class UserPreferencesSubscriptionNotifications(BaseModel):
    """
    UserPreferencesSubscriptionNotifications
    """
    long_term_auction_updates: SubscriptionNotificationPreferenceWithEmail = Field(default=..., alias="longTermAuctionUpdates")
    day_ahead_auction_updates: SubscriptionNotificationPreference = Field(default=..., alias="dayAheadAuctionUpdates")
    intraday_auction_updates: SubscriptionNotificationPreference = Field(default=..., alias="intradayAuctionUpdates")
    buy_now_transmission_rights_offers: SubscriptionNotificationPreferenceWithEmail = Field(default=..., alias="buyNowTransmissionRightsOffers")
    unplanned_outage_updates: SubscriptionNotificationPreferenceWithEmail = Field(default=..., alias="unplannedOutageUpdates")
    curtailment: SubscriptionNotificationPreferenceWithEmail = Field(...)
    __properties = ["longTermAuctionUpdates", "dayAheadAuctionUpdates", "intradayAuctionUpdates", "buyNowTransmissionRightsOffers", "unplannedOutageUpdates", "curtailment"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> UserPreferencesSubscriptionNotifications:
        """Create an instance of UserPreferencesSubscriptionNotifications from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of long_term_auction_updates
        if self.long_term_auction_updates:
            _dict['longTermAuctionUpdates'] = self.long_term_auction_updates.to_dict()
        # override the default output from pydantic by calling `to_dict()` of day_ahead_auction_updates
        if self.day_ahead_auction_updates:
            _dict['dayAheadAuctionUpdates'] = self.day_ahead_auction_updates.to_dict()
        # override the default output from pydantic by calling `to_dict()` of intraday_auction_updates
        if self.intraday_auction_updates:
            _dict['intradayAuctionUpdates'] = self.intraday_auction_updates.to_dict()
        # override the default output from pydantic by calling `to_dict()` of buy_now_transmission_rights_offers
        if self.buy_now_transmission_rights_offers:
            _dict['buyNowTransmissionRightsOffers'] = self.buy_now_transmission_rights_offers.to_dict()
        # override the default output from pydantic by calling `to_dict()` of unplanned_outage_updates
        if self.unplanned_outage_updates:
            _dict['unplannedOutageUpdates'] = self.unplanned_outage_updates.to_dict()
        # override the default output from pydantic by calling `to_dict()` of curtailment
        if self.curtailment:
            _dict['curtailment'] = self.curtailment.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> UserPreferencesSubscriptionNotifications:
        """Create an instance of UserPreferencesSubscriptionNotifications from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return UserPreferencesSubscriptionNotifications.parse_obj(obj)

        _obj = UserPreferencesSubscriptionNotifications.parse_obj({
            "long_term_auction_updates": SubscriptionNotificationPreferenceWithEmail.from_dict(obj.get("longTermAuctionUpdates")) if obj.get("longTermAuctionUpdates") is not None else None,
            "day_ahead_auction_updates": SubscriptionNotificationPreference.from_dict(obj.get("dayAheadAuctionUpdates")) if obj.get("dayAheadAuctionUpdates") is not None else None,
            "intraday_auction_updates": SubscriptionNotificationPreference.from_dict(obj.get("intradayAuctionUpdates")) if obj.get("intradayAuctionUpdates") is not None else None,
            "buy_now_transmission_rights_offers": SubscriptionNotificationPreferenceWithEmail.from_dict(obj.get("buyNowTransmissionRightsOffers")) if obj.get("buyNowTransmissionRightsOffers") is not None else None,
            "unplanned_outage_updates": SubscriptionNotificationPreferenceWithEmail.from_dict(obj.get("unplannedOutageUpdates")) if obj.get("unplannedOutageUpdates") is not None else None,
            "curtailment": SubscriptionNotificationPreferenceWithEmail.from_dict(obj.get("curtailment")) if obj.get("curtailment") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 6.0.2
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class VatRateType(str, Enum):
    """
    VatRateType
    """

    """
    allowed enum values
    """
    GB_SALES_VAT = 'GB_SALES_VAT'
    GB_VAT = 'GB_VAT'
    GB_SALES_SERVICES_OUTSIDE_EU = 'GB_SALES_SERVICES_OUTSIDE_EU'
    GB_SALES_SERVICES_WITHIN_EU = 'GB_SALES_SERVICES_WITHIN_EU'
    NL_SALES_VAT = 'NL_SALES_VAT'
    NL_SALES_VAT_ZERO = 'NL_SALES_VAT_ZERO'
    NL_SALES_SERVICES_OUTSIDE_EU = 'NL_SALES_SERVICES_OUTSIDE_EU'
    NL_SALES_SERVICES_WITHIN_EU = 'NL_SALES_SERVICES_WITHIN_EU'

    @classmethod
    def from_json(cls, json_str: str) -> VatRateType:
        """Create an instance of VatRateType from a JSON string"""
        return VatRateType(json.loads(json_str))





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 6.0.2
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from empire_platform_api_public_client_legacy.models.user_preferences import UserPreferences  # noqa: E501

class TestUserPreferences(unittest.TestCase):
    """UserPreferences unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UserPreferences:
        """Test UserPreferences
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UserPreferences`
        """
        model = UserPreferences()  # noqa: E501
        if include_optional:
            return UserPreferences(
                general_notifications = empire_platform_api_public_client_legacy.models.user_preferences_general_notifications.UserPreferences_generalNotifications(
                    critical_alert = empire_platform_api_public_client_legacy.models.general_notification_preference_with_sms.GeneralNotificationPreferenceWithSms(
                        email = True, 
                        sms = True, ), 
                    critical = empire_platform_api_public_client_legacy.models.general_notification_preference.GeneralNotificationPreference(
                        email = True, ), 
                    major = empire_platform_api_public_client_legacy.models.general_notification_preference.GeneralNotificationPreference(
                        email = True, ), 
                    normal = , ),
                subscription_notifications = empire_platform_api_public_client_legacy.models.user_preferences_subscription_notifications.UserPreferences_subscriptionNotifications(
                    long_term_auction_updates = empire_platform_api_public_client_legacy.models.subscription_notification_preference_with_email.SubscriptionNotificationPreferenceWithEmail(
                        browser = True, 
                        email = True, ), 
                    day_ahead_auction_updates = empire_platform_api_public_client_legacy.models.subscription_notification_preference.SubscriptionNotificationPreference(
                        browser = True, ), 
                    intraday_auction_updates = empire_platform_api_public_client_legacy.models.subscription_notification_preference.SubscriptionNotificationPreference(
                        browser = True, ), 
                    buy_now_transmission_rights_offers = empire_platform_api_public_client_legacy.models.subscription_notification_preference_with_email.SubscriptionNotificationPreferenceWithEmail(
                        browser = True, 
                        email = True, ), 
                    unplanned_outage_updates = , 
                    curtailment = , ),
                appearance = 'DEFAULT',
                timescale_preferences = empire_platform_api_public_client_legacy.models.timescale_preferences.TimescalePreferences(
                    long_term = True, 
                    day_ahead = True, 
                    intraday = True, )
            )
        else:
            return UserPreferences(
                general_notifications = empire_platform_api_public_client_legacy.models.user_preferences_general_notifications.UserPreferences_generalNotifications(
                    critical_alert = empire_platform_api_public_client_legacy.models.general_notification_preference_with_sms.GeneralNotificationPreferenceWithSms(
                        email = True, 
                        sms = True, ), 
                    critical = empire_platform_api_public_client_legacy.models.general_notification_preference.GeneralNotificationPreference(
                        email = True, ), 
                    major = empire_platform_api_public_client_legacy.models.general_notification_preference.GeneralNotificationPreference(
                        email = True, ), 
                    normal = , ),
                subscription_notifications = empire_platform_api_public_client_legacy.models.user_preferences_subscription_notifications.UserPreferences_subscriptionNotifications(
                    long_term_auction_updates = empire_platform_api_public_client_legacy.models.subscription_notification_preference_with_email.SubscriptionNotificationPreferenceWithEmail(
                        browser = True, 
                        email = True, ), 
                    day_ahead_auction_updates = empire_platform_api_public_client_legacy.models.subscription_notification_preference.SubscriptionNotificationPreference(
                        browser = True, ), 
                    intraday_auction_updates = empire_platform_api_public_client_legacy.models.subscription_notification_preference.SubscriptionNotificationPreference(
                        browser = True, ), 
                    buy_now_transmission_rights_offers = empire_platform_api_public_client_legacy.models.subscription_notification_preference_with_email.SubscriptionNotificationPreferenceWithEmail(
                        browser = True, 
                        email = True, ), 
                    unplanned_outage_updates = , 
                    curtailment = , ),
                appearance = 'DEFAULT',
                timescale_preferences = empire_platform_api_public_client_legacy.models.timescale_preferences.TimescalePreferences(
                    long_term = True, 
                    day_ahead = True, 
                    intraday = True, ),
        )
        """

    def testUserPreferences(self):
        """Test UserPreferences"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
